// LICENSE : MIT
"use strict";
Object.defineProperty(exports, '__esModule', {
    value: true
});
exports.lookupLanguageByAceMode = lookupLanguageByAceMode;
exports.lookupLanguageByExtension = lookupLanguageByExtension;
exports.getLang = getLang;
var path = require('path');
var language_map = require('language-map');

function lookupLanguageByAceMode(commands) {
    var resultAceMode = undefined;
    commands.forEach(function (command) {
        var matchAceModes = /lang\-(.+)/g.exec(command);
        if (matchAceModes == null) {
            return;
        }
        var matchLang = matchAceModes[1];
        if (!matchLang) {
            return;
        }
        Object.keys(language_map).some(function (langKey) {
            var aceMode = language_map[langKey]["aceMode"];
            if (matchLang === aceMode) {
                resultAceMode = aceMode;
            }
        });
    });
    return resultAceMode;
}

function lookupLanguageByExtension(ext) {
    var aceMode = undefined;
    Object.keys(language_map).some(function (langKey) {
        var extensions = language_map[langKey]["extensions"];
        /* TODO: These lang has not extensions
         Ant Build System
         Isabelle ROOT
         Maven POMAnt Build System
         */
        if (!extensions) {
            return false;
        }
        return extensions.some(function (extension) {
            if (ext === extension) {
                aceMode = language_map[langKey]["aceMode"];
            }
        });
    });
    return aceMode;
}

function getLang(commands, filePath) {
    var lang = lookupLanguageByAceMode(commands);
    if (lang) {
        return lang;
    }
    var ext = path.extname(filePath);
    return lookupLanguageByExtension(ext) || ext;
}
//# sourceMappingURL=language-detection.js.map