// LICENSE : MIT
"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});

var _slicedToArray = (function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; })();

exports.splitLabelToCommands = splitLabelToCommands;
exports.containIncludeCommand = containIncludeCommand;
exports.getSliceRange = getSliceRange;
exports.embedCode = embedCode;
exports.generateEmbedCode = generateEmbedCode;
exports.parse = parse;
var fs = require("fs");
var path = require('path');

var _require = require("./language-detection");

var getLang = _require.getLang;

var markdownLinkFormatRegExp = /\[([^\]]*?)\]\(([^\)]*?)\)/gm;
/**
 * split label to commands
 * @param {string} label
 * @returns {Array}
 */

function splitLabelToCommands() {
    var label = arguments.length <= 0 || arguments[0] === undefined ? "" : arguments[0];

    var result = label.split(/(:|[,\s])/);
    if (!result) {
        return [];
    }
    // remove null command
    return result.map(function (command) {
        return command.trim();
    }).filter(function (command) {
        return command.length > 0;
    });
}

/**
 * if contain "include" or "import" command, then return true
 * @param {Array} commands
 * @returns {boolean}
 */

function containIncludeCommand() {
    var commands = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];

    var reg = /^(include|import)$/;
    return commands.some(function (command) {
        return reg.test(command.trim());
    });
}

/*
 format: [import:<start-lineNumber>-<end-lineNumber>](path/to/file)
 lineNumber start with 1.

 Patterns:

 All: [import, hello-world.js](../src/hello-world.js)
 1-2: [import:1-2, hello-world.js](../src/hello-world.js)
 2-3: [import:2-3, hello-world.js](../src/hello-world.js)
 2>=: [import:2-, hello-world.js](../src/hello-world.js)
 <=3: [import:-3, hello-world.js](../src/hello-world.js)
 */

function getSliceRange(label) {
    var reg = /^(?:include|import):?(\d*)-?(\d*)[,\s]?.*$/;
    var res = reg.exec(label);

    // return ['', ''] if not matched.
    return res ? res.slice(1) : [];
}

function embedCode(lang, filePath, originalPath, start, end) {
    var code = fs.readFileSync(filePath, "utf-8");
    var slicedCode = sliceCode(code, start, end);
    var fileName = path.basename(filePath);
    var content = slicedCode.trim();
    return generateEmbedCode(lang, fileName, originalPath, content);
}

function generateEmbedCode(lang, fileName, originalPath, content) {
    return "> <a name=\"" + fileName + "\" href=\"" + originalPath + "\">" + fileName + "</a>\n\n``` " + lang + "\n" + content + "\n```";
}

function sliceCode(code, start, end) {
    if (start === '' && end === '') {
        return code;
    }

    var splitted = code.split('\n');
    if (start === '') {
        start = 1;
    }
    if (end === '') {
        end = splitted.length;
    }
    return splitted.slice(start - 1, end).join('\n');
}

function parse(content, baseDir) {
    var results = [];
    var res = undefined;
    while (res = markdownLinkFormatRegExp.exec(content)) {
        var _res = res;

        var _res2 = _slicedToArray(_res, 3);

        var all = _res2[0];
        var label = _res2[1];
        var filePath = _res2[2];

        var commands = splitLabelToCommands(label);
        if (containIncludeCommand(commands)) {
            var lang = getLang(commands, filePath);

            var _getSliceRange = getSliceRange(label);

            var _getSliceRange2 = _slicedToArray(_getSliceRange, 2);

            var start = _getSliceRange2[0];
            var end = _getSliceRange2[1];

            var absolutePath = path.resolve(baseDir, filePath);
            var replacedContent = embedCode(lang, absolutePath, filePath, start, end);
            results.push({
                target: all,
                replaced: replacedContent
            });
        }
    }
    return results;
}
//# sourceMappingURL=parser.js.map